@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 sub new {
 	my $class = shift;
@@ -91,8 +91,7 @@ sub return_value {
 
 sub AUTOLOAD {
 	my $self = shift;
-	my $key = our $AUTOLOAD;
-	return if $key =~ /DESTROY$/;
+	my $key  = our $AUTOLOAD;
 	$key =~ s/^.*:://;
 	return $self->get_value($key);
 }
@@ -104,6 +103,10 @@ sub get_value {
 	return wantarray && ref $value eq 'ARRAY'? @$value: $value;
 }
 
+# Improves performance by not having to send DESTROY calls
+# through AUTOLOAD, and not having to check for DESTROY in AUTOLOAD.
+sub DESTROY () { }
+
 1;
 
 __END__
